
Installation
============

Project is available on PyPI_ and Github_:


Install via pip
---------------

.. code:: bash

    pip install vk


Install via setuptools
----------------------

Get package by one of these ways and install

- Download from `PyPI page`_
- Clone `Git repo`_
- Download `Github release <https://github.com/voronind/vk/releases>`_

.. code:: bash

    python setup.py install


.. _PyPI page: PyPI_
.. _Git repo: Github_

.. _PyPI: https://pypi.org/project/vk/
.. _Github: https://github.com/voronind/vk
